Index — Pootle 2.8.0b3 documentation

# Index

Symbols | A | C | D | E | F | I | L | M | O | P | R | S | T | U | V | W

## Symbols

--after-revision changed_languages command line option --all flush_cache command line option verify_user command line option --check calculate_checks command line option test_checks command line option --config init command line option --data dump command line option --db init command line option --db-host init command line option --db-name init command line option --db-port init command line option --db-user init command line option --dev webpack command line option --display-name update_tmserver command line option --django-cache flush_cache command line option --dry-run update_tmserver command line option --force sync_stores command line option update_stores command line option --include-anonymous contributors command line option --include-disabled-projects update_tmserver command line option --mailmerge contributors command line option --modified-since list_languages command line option list_projects command line option --no-delete merge_user command line option --no-projects initdb command line option --no-rq command line option --noinput command line option --overwrite sync_stores command line option update_stores command line option --project, --language command line option | --rebuild update_tmserver command line option --refresh update_tmserver command line option --reset refresh_scores command line option --restore revision command line option --rqdata flush_cache command line option --since contributors command line option --skip-missing sync_stores command line option --sort-by contributors command line option --source, --target test_checks command line option --stats dump command line option flush_cache command line option --target-language update_tmserver command line option --tm update_tmserver command line option --unit test_checks command line option --until contributors command line option --user import command line option -a <key> <value>, --append <key> <value> config command line option -c <key>, --clear <key> config command line option -d, --deserializers list_serializers command line option -g <key>, --get <key> config command line option -j, --json config command line option -l <key>, --list <key> config command line option -m, --model list_serializers command line option -o <field>, --object-field <field> config command line option -s <key> <value>, --set <key> <value> config command line option

## A

add_vfolders django-admin command | AMAGAMA_URL setting

## C

calculate_checks django-admin command calculate_checks command line option --check changed_languages django-admin command changed_languages command line option --after-revision clear_stats django-admin command command line option --no-rq --noinput --project, --language commit_to_vcs django-admin command | config django-admin command config command line option -a <key> <value>, --append <key> <value> -c <key>, --clear <key> -g <key>, --get <key> -j, --json -l <key>, --list <key> -o <field>, --object-field <field> -s <key> <value>, --set <key> <value> content_type object content_type config command line option contributors django-admin command contributors command line option --include-anonymous --mailmerge --since --sort-by --until CONTRIBUTORS_EXCLUDED_NAMES setting CONTRIBUTORS_EXCLUDED_PROJECT_NAMES setting

## D

DESCRIPTION setting django-admin command add_vfolders calculate_checks changed_languages clear_stats commit_to_vcs config contributors dump export find_duplicate_emails flush_cache import init initdb last_change_id list_languages list_projects list_serializers merge_user purge_user refresh_scores refresh_stats retry_failed_jobs revision run_cherrypy start sync_stores test_checks update_from_vcs update_stores update_tmserver update_user_email verify_user webpack | dump django-admin command dump command line option --data --stats

## E

ENABLE_ALT_SRC setting environment variable POOTLE_SETTINGS, [1] PYTHONPATH | export django-admin command EXPORTED_DIRECTORY_MODE setting

## F

find_duplicate_emails django-admin command flush_cache django-admin command flush_cache command line option --all --django-cache --rqdata --stats | FUZZY_MATCH_MAX_LENGTH setting FUZZY_MATCH_MIN_SIMILARITY setting

## I

import django-admin command import command line option --user init django-admin command | init command line option --config --db --db-host --db-name --db-port --db-user The configuration file to write to. initdb django-admin command initdb command line option --no-projects

## L

last_change_id django-admin command list_languages django-admin command list_languages command line option --modified-since list_projects django-admin command | list_projects command line option --modified-since list_serializers django-admin command list_serializers command line option -d, --deserializers -m, --model

## M

MAX_AUTOTERMS setting merge_user django-admin command | merge_user command line option --no-delete MIN_AUTOTERMS setting

## O

object config command line option

## P

PARSE_POOL_CULL_FREQUENCY setting PARSE_POOL_SIZE setting POOTLE_CACHE_TIMEOUT setting POOTLE_CAPTCHA_ENABLED setting POOTLE_CONTACT_EMAIL setting POOTLE_CONTACT_ENABLED setting POOTLE_CONTACT_REPORT_EMAIL setting POOTLE_CUSTOM_TEMPLATE_CONTEXT setting POOTLE_EXPORT_VIEW_LIMIT setting POOTLE_INSTANCE_ID setting POOTLE_LEGALPAGE_NOCHECK_PREFIXES setting POOTLE_LOG_DIRECTORY setting POOTLE_MARKUP_FILTER setting POOTLE_META_USERS setting POOTLE_MT_BACKENDS setting POOTLE_QUALITY_CHECKER setting | POOTLE_REPORTS_MARK_FUNC setting POOTLE_SCORE_COEFFICIENTS setting POOTLE_SETTINGS, [1] POOTLE_SIGNUP_ENABLED setting POOTLE_SYNC_FILE_MODE setting POOTLE_TITLE setting POOTLE_TM_SERVER setting POOTLE_TM_SERVER-INDEX_NAME setting POOTLE_TM_SERVER-MIN_SIMILARITY setting POOTLE_TM_SERVER-WEIGHT setting POOTLE_TOP_STATS_CACHE_TIMEOUT setting POOTLE_TRANSLATION_DIRECTORY setting POOTLE_WORDCOUNT_FUNC setting purge_user django-admin command PYTHONPATH

## R

refresh_scores django-admin command refresh_scores command line option --reset refresh_stats django-admin command retry_failed_jobs django-admin command | revision django-admin command revision command line option --restore run_cherrypy django-admin command

## S

setting AMAGAMA_URL CONTRIBUTORS_EXCLUDED_NAMES CONTRIBUTORS_EXCLUDED_PROJECT_NAMES DESCRIPTION ENABLE_ALT_SRC EXPORTED_DIRECTORY_MODE FUZZY_MATCH_MAX_LENGTH FUZZY_MATCH_MIN_SIMILARITY MAX_AUTOTERMS MIN_AUTOTERMS PARSE_POOL_CULL_FREQUENCY PARSE_POOL_SIZE POOTLE_CACHE_TIMEOUT POOTLE_CAPTCHA_ENABLED POOTLE_CONTACT_EMAIL POOTLE_CONTACT_ENABLED POOTLE_CONTACT_REPORT_EMAIL POOTLE_CUSTOM_TEMPLATE_CONTEXT POOTLE_EXPORT_VIEW_LIMIT POOTLE_INSTANCE_ID POOTLE_LEGALPAGE_NOCHECK_PREFIXES POOTLE_LOG_DIRECTORY POOTLE_MARKUP_FILTER POOTLE_META_USERS POOTLE_MT_BACKENDS POOTLE_QUALITY_CHECKER POOTLE_REPORTS_MARK_FUNC POOTLE_SCORE_COEFFICIENTS POOTLE_SIGNUP_ENABLED POOTLE_SYNC_FILE_MODE POOTLE_TITLE POOTLE_TM_SERVER POOTLE_TM_SERVER-INDEX_NAME POOTLE_TM_SERVER-MIN_SIMILARITY POOTLE_TM_SERVER-WEIGHT POOTLE_TOP_STATS_CACHE_TIMEOUT POOTLE_TRANSLATION_DIRECTORY POOTLE_WORDCOUNT_FUNC VCS_DIRECTORY start django-admin command | sync_stores django-admin command sync_stores command line option --force --overwrite --skip-missing

## T

test_checks django-admin command test_checks command line option --check --source, --target --unit | The configuration file to write to. init command line option

## U

update_from_vcs django-admin command update_stores django-admin command update_stores command line option --force --overwrite | update_tmserver django-admin command update_tmserver command line option --display-name --dry-run --include-disabled-projects --rebuild --refresh --target-language --tm update_user_email django-admin command

## V

VCS_DIRECTORY setting verify_user django-admin command | verify_user command line option --all

## W

webpack django-admin command | webpack command line option --dev